@@ -1,5 +1,6 @@
 import sys
-from html2excel import ExcelParser
+# from html2excel import ExcelParser
+from html2excel.excel.parser import ExcelParser
 
 def run():
     if len(sys.argv) == 3:
@@ -11,6 +12,7 @@ def run():
         # First argument for file name, we'll ignore that
         print("Expected 2 arguments. Got {num}".format(num=len(sys.argv)-1))
 
+
 if __name__ == "__main__":
     run()
 
